##  Managing Templates
Admins and non-admin users with appropriate permissions can manage architecture decision templates on the Templates page. Here, you can:
  * Edit templates: Editing a template affects all architecture decisions based on it.
    * Changing the ID prefix affects the IDs of all decisions based on this template, so proceed with caution.
    * Deleting a component within a template permanently removes all content stored in that component across all decisions based on the template. Always proceed with caution to avoid unintentional data loss.
  * Activate or deactivate templates: You can activate or deactivate a template by switching the toggle next to the template name. Deactivating a template doesn’t delete architecture decisions based on it.
  * Duplicate templates: You can create new templates by duplicating existing ones, which saves time when you need templates with a similar structure. To duplicate a template, hover over it, then click the duplicate icon that appears on the right.
  * Delete templates: Deleting a template deletes all architecture decisions based on it. Always proceed with caution to avoid unintentional data loss.


**Caution**
When deleting templates or components within a template, always proceed with caution to avoid unintentional data loss. This action affects all architecture decisions based on those templates.
